You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucy.apache.org by lo...@apache.org on 2012/10/05 19:41:51 UTC

[lucy-commits] svn commit: r1394684 - /lucy/trunk/charmonizer/src/Charmonizer/Core/ConfWriterRuby.c

Author: logie
Date: Fri Oct  5 17:41:51 2012
New Revision: 1394684

URL: http://svn.apache.org/viewvc?rev=1394684&view=rev
Log:
Fixed some minor syntax errors that were not correct for ruby

Modified:
    lucy/trunk/charmonizer/src/Charmonizer/Core/ConfWriterRuby.c

Modified: lucy/trunk/charmonizer/src/Charmonizer/Core/ConfWriterRuby.c
URL: http://svn.apache.org/viewvc/lucy/trunk/charmonizer/src/Charmonizer/Core/ConfWriterRuby.c?rev=1394684&r1=1394683&r2=1394684&view=diff
==============================================================================
--- lucy/trunk/charmonizer/src/Charmonizer/Core/ConfWriterRuby.c (original)
+++ lucy/trunk/charmonizer/src/Charmonizer/Core/ConfWriterRuby.c Fri Oct  5 17:41:51 2012
@@ -82,9 +82,9 @@ S_open_config_rb(void) {
             "\n"
             "module Charmony\n"
             "\n"
-            "%%defs\n"
+            "defs = {}\n"
             "\n"
-            "def config\n\\%%defs\nend\n"
+            "def config\n\defs\nend\n"
             "\n"
            );
 }
@@ -162,9 +162,9 @@ S_ConfWriterRuby_add_def(const char *sym
     }
     quoted_sym = S_ConfWriterRuby_quotify(sym, sym_buf, CFRUBY_MAX_BUF);
 
     /* Quote value or use "undef". */
     if (!value) {
-        strcpy(value_buf, "undef");
+        strcpy(value_buf, "nil");
         quoted_value = value_buf;
     }
     else {
@@ -162,9 +162,9 @@ S_ConfWriterRuby_add_def(const char *sym
     quoted_sym = S_ConfWriterRuby_quotify(sym, sym_buf, CFRUBY_MAX_BUF);
 
-    /* Quote value or use "undef". */
+    /* Quote value or use "nil". */
     if (!value) {